package com.dashitech.migration.task.incident;

import com.dashitech.migration.BaseTask;
import com.dashitech.migration.SqlTask;
import com.dashitech.migration.core.DataMigrationter;
import com.dashitech.migration.core.FieldMapper;
import com.dashitech.migration.util.JdbcUtil;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * Created by CX on 2024/10/10.
 */
@Component
public class IncidentAssignManagerTask extends BaseTask {

    @Autowired
    SqlTask hospitalTask;

    @Autowired
    SqlTask departmentTask;

    public static Log log = LogFactory.getLog(IncidentAssignManagerTask.class);

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void start() {
        log.info(" *** IncidentAssignManagerTask start 开始 *** ");

        StringBuffer sb = new StringBuffer();
        sb.append(" select * from itsm_incident ");

        List list = jdbcTemplateMdv2.queryForList(sb.toString());

        FieldMapper mapper = new FieldMapper();
        mapper.addOperationRemove("id").addOperationRemove("version");
        mapper.trans2JdbcRow(list);

        FieldMapper userMapper = loadCache();
        JdbcUtil jdbcUtil = new JdbcUtil(jdbcTemplateHsms);
        jdbcUtil.batchPageInsert("itsm_itsm_incident", mapper.getRows());

        //clear释放内存
        mapper.clear();
        userMapper.clear();
    }

    @Override
    public FieldMapper loadCache() {
        log.info(" *** IncidentAssignManagerTask loadCache 开始 *** ");

        String sql = " select id,ACCOUNT,delete_flag from itsm_incident ";
        List<Map<String, Object>> list = jdbcTemplateHsms.queryForList(sql);
        sql = " select id,ACCOUNT,delete_flag from itsm_itsm_incident ";
        List<Map<String, Object>> list2 = jdbcTemplateMdv2.queryForList(sql);

        FieldMapper mapper = new FieldMapper();
        mapper.addFieldMapper("ACCOUNT", "ACCOUNT");
        mapper.addFieldMapper("delete_flag", "delete_flag");

        DataMigrationter.loadCache(list, list2, mapper);

        return mapper;
    }
}
